/***********************************************************************
*
**
*        Automatic header module from ASNTOOL
*
************************************************************************/

#ifndef _ASNTOOL_
#include <asn.h>
#endif

static char * asnfilename = "asnmacro.h54";
static AsnValxNode avnx[571] = {
    {20,"acronym" ,1,0.0,&avnx[1] } ,
    {20,"anamorph" ,2,0.0,&avnx[2] } ,
    {20,"authority" ,3,0.0,&avnx[3] } ,
    {20,"bio-material" ,4,0.0,&avnx[4] } ,
    {20,"biotype" ,5,0.0,&avnx[5] } ,
    {20,"biovar" ,6,0.0,&avnx[6] } ,
    {20,"breed" ,7,0.0,&avnx[7] } ,
    {20,"cell-line" ,8,0.0,&avnx[8] } ,
    {20,"cell-type" ,9,0.0,&avnx[9] } ,
    {20,"chemovar" ,10,0.0,&avnx[10] } ,
    {20,"chromosome" ,11,0.0,&avnx[11] } ,
    {20,"clone" ,12,0.0,&avnx[12] } ,
    {20,"clone-lib" ,13,0.0,&avnx[13] } ,
    {20,"collected-by" ,14,0.0,&avnx[14] } ,
    {20,"collection-date" ,15,0.0,&avnx[15] } ,
    {20,"common" ,16,0.0,&avnx[16] } ,
    {20,"common-name" ,17,0.0,&avnx[17] } ,
    {20,"country" ,18,0.0,&avnx[18] } ,
    {20,"cultivar" ,19,0.0,&avnx[19] } ,
    {20,"culture-collection" ,20,0.0,&avnx[20] } ,
    {20,"dev-stage" ,21,0.0,&avnx[21] } ,
    {20,"division" ,22,0.0,&avnx[22] } ,
    {20,"dosage" ,23,0.0,&avnx[23] } ,
    {20,"ecotype" ,24,0.0,&avnx[24] } ,
    {20,"endogenous-virus-name" ,25,0.0,&avnx[25] } ,
    {20,"environmental-sample" ,26,0.0,&avnx[26] } ,
    {20,"forma" ,27,0.0,&avnx[27] } ,
    {20,"forma-specialis" ,28,0.0,&avnx[28] } ,
    {20,"frequency" ,29,0.0,&avnx[29] } ,
    {20,"fwd-primer-name" ,30,0.0,&avnx[30] } ,
    {20,"fwd-primer-seq" ,31,0.0,&avnx[31] } ,
    {20,"gb-acronym" ,32,0.0,&avnx[32] } ,
    {20,"gb-anamorph" ,33,0.0,&avnx[33] } ,
    {20,"gb-synonym" ,34,0.0,&avnx[34] } ,
    {20,"genotype" ,35,0.0,&avnx[35] } ,
    {20,"germline" ,36,0.0,&avnx[36] } ,
    {20,"group" ,37,0.0,&avnx[37] } ,
    {20,"haplotype" ,38,0.0,&avnx[38] } ,
    {20,"identified-by" ,39,0.0,&avnx[39] } ,
    {20,"insertion-seq-name" ,40,0.0,&avnx[40] } ,
    {20,"isolate" ,41,0.0,&avnx[41] } ,
    {20,"isolation-source" ,42,0.0,&avnx[42] } ,
    {20,"lab-host" ,43,0.0,&avnx[43] } ,
    {20,"lat-lon" ,44,0.0,&avnx[44] } ,
    {20,"lineage" ,45,0.0,&avnx[45] } ,
    {20,"map" ,46,0.0,&avnx[46] } ,
    {20,"metagenome-source" ,47,0.0,&avnx[47] } ,
    {20,"metagenomic" ,48,0.0,&avnx[48] } ,
    {20,"old-lineage" ,49,0.0,&avnx[49] } ,
    {20,"old-name" ,50,0.0,&avnx[50] } ,
    {20,"orgmod-note" ,51,0.0,&avnx[51] } ,
    {20,"nat-host" ,52,0.0,&avnx[52] } ,
    {20,"pathovar" ,53,0.0,&avnx[53] } ,
    {20,"plasmid-name" ,54,0.0,&avnx[54] } ,
    {20,"plastid-name" ,55,0.0,&avnx[55] } ,
    {20,"pop-variant" ,56,0.0,&avnx[56] } ,
    {20,"rearranged" ,57,0.0,&avnx[57] } ,
    {20,"rev-primer-name" ,58,0.0,&avnx[58] } ,
    {20,"rev-primer-seq" ,59,0.0,&avnx[59] } ,
    {20,"segment" ,60,0.0,&avnx[60] } ,
    {20,"serogroup" ,61,0.0,&avnx[61] } ,
    {20,"serotype" ,62,0.0,&avnx[62] } ,
    {20,"serovar" ,63,0.0,&avnx[63] } ,
    {20,"sex" ,64,0.0,&avnx[64] } ,
    {20,"specimen-voucher" ,65,0.0,&avnx[65] } ,
    {20,"strain" ,66,0.0,&avnx[66] } ,
    {20,"subclone" ,67,0.0,&avnx[67] } ,
    {20,"subgroup" ,68,0.0,&avnx[68] } ,
    {20,"subsource-note" ,69,0.0,&avnx[69] } ,
    {20,"sub-species" ,70,0.0,&avnx[70] } ,
    {20,"substrain" ,71,0.0,&avnx[71] } ,
    {20,"subtype" ,72,0.0,&avnx[72] } ,
    {20,"synonym" ,73,0.0,&avnx[73] } ,
    {20,"taxname" ,74,0.0,&avnx[74] } ,
    {20,"teleomorph" ,75,0.0,&avnx[75] } ,
    {20,"tissue-lib" ,76,0.0,&avnx[76] } ,
    {20,"tissue-type" ,77,0.0,&avnx[77] } ,
    {20,"transgenic" ,78,0.0,&avnx[78] } ,
    {20,"transposon-name" ,79,0.0,&avnx[79] } ,
    {20,"type" ,80,0.0,&avnx[80] } ,
    {20,"variety" ,81,0.0,&avnx[81] } ,
    {20,"specimen-voucher-INST" ,82,0.0,&avnx[82] } ,
    {20,"specimen-voucher-COLL" ,83,0.0,&avnx[83] } ,
    {20,"specimen-voucher-SpecID" ,84,0.0,&avnx[84] } ,
    {20,"culture-collection-INST" ,85,0.0,&avnx[85] } ,
    {20,"culture-collection-COLL" ,86,0.0,&avnx[86] } ,
    {20,"culture-collection-SpecID" ,87,0.0,&avnx[87] } ,
    {20,"bio-material-INST" ,88,0.0,&avnx[88] } ,
    {20,"bio-material-COLL" ,89,0.0,&avnx[89] } ,
    {20,"bio-material-SpecID" ,90,0.0,&avnx[90] } ,
    {20,"all-notes" ,91,0.0,&avnx[91] } ,
    {20,"mating-type" ,92,0.0,&avnx[92] } ,
    {20,"linkage-group" ,93,0.0,&avnx[93] } ,
    {20,"haplogroup" ,94,0.0,&avnx[94] } ,
    {20,"all-quals" ,95,0.0,&avnx[95] } ,
    {20,"dbxref" ,96,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[97] } ,
    {20,"genomic" ,1,0.0,&avnx[98] } ,
    {20,"chloroplast" ,2,0.0,&avnx[99] } ,
    {20,"chromoplast" ,3,0.0,&avnx[100] } ,
    {20,"kinetoplast" ,4,0.0,&avnx[101] } ,
    {20,"mitochondrion" ,5,0.0,&avnx[102] } ,
    {20,"plastid" ,6,0.0,&avnx[103] } ,
    {20,"macronuclear" ,7,0.0,&avnx[104] } ,
    {20,"extrachrom" ,8,0.0,&avnx[105] } ,
    {20,"plasmid" ,9,0.0,&avnx[106] } ,
    {20,"transposon" ,10,0.0,&avnx[107] } ,
    {20,"insertion-seq" ,11,0.0,&avnx[108] } ,
    {20,"cyanelle" ,12,0.0,&avnx[109] } ,
    {20,"proviral" ,13,0.0,&avnx[110] } ,
    {20,"virion" ,14,0.0,&avnx[111] } ,
    {20,"nucleomorph" ,15,0.0,&avnx[112] } ,
    {20,"apicoplast" ,16,0.0,&avnx[113] } ,
    {20,"leucoplast" ,17,0.0,&avnx[114] } ,
    {20,"proplastid" ,18,0.0,&avnx[115] } ,
    {20,"endogenous-virus" ,19,0.0,&avnx[116] } ,
    {20,"hydrogenosome" ,20,0.0,&avnx[117] } ,
    {20,"chromosome" ,21,0.0,&avnx[118] } ,
    {20,"chromatophore" ,22,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[120] } ,
    {20,"natural" ,1,0.0,&avnx[121] } ,
    {20,"natmut" ,2,0.0,&avnx[122] } ,
    {20,"mut" ,3,0.0,&avnx[123] } ,
    {20,"artificial" ,4,0.0,&avnx[124] } ,
    {20,"synthetic" ,5,0.0,&avnx[125] } ,
    {20,"other" ,255,0.0,NULL } ,
    {20,"any" ,0,0.0,&avnx[127] } ,
    {20,"gene" ,1,0.0,&avnx[128] } ,
    {20,"org" ,2,0.0,&avnx[129] } ,
    {20,"cds" ,3,0.0,&avnx[130] } ,
    {20,"prot" ,4,0.0,&avnx[131] } ,
    {20,"preRNA" ,5,0.0,&avnx[132] } ,
    {20,"mRNA" ,6,0.0,&avnx[133] } ,
    {20,"tRNA" ,7,0.0,&avnx[134] } ,
    {20,"rRNA" ,8,0.0,&avnx[135] } ,
    {20,"snRNA" ,9,0.0,&avnx[136] } ,
    {20,"scRNA" ,10,0.0,&avnx[137] } ,
    {20,"otherRNA" ,11,0.0,&avnx[138] } ,
    {20,"pub" ,12,0.0,&avnx[139] } ,
    {20,"seq" ,13,0.0,&avnx[140] } ,
    {20,"imp" ,14,0.0,&avnx[141] } ,
    {20,"allele" ,15,0.0,&avnx[142] } ,
    {20,"attenuator" ,16,0.0,&avnx[143] } ,
    {20,"c-region" ,17,0.0,&avnx[144] } ,
    {20,"caat-signal" ,18,0.0,&avnx[145] } ,
    {20,"imp-CDS" ,19,0.0,&avnx[146] } ,
    {20,"conflict" ,20,0.0,&avnx[147] } ,
    {20,"d-loop" ,21,0.0,&avnx[148] } ,
    {20,"d-segment" ,22,0.0,&avnx[149] } ,
    {20,"enhancer" ,23,0.0,&avnx[150] } ,
    {20,"exon" ,24,0.0,&avnx[151] } ,
    {20,"gC-signal" ,25,0.0,&avnx[152] } ,
    {20,"iDNA" ,26,0.0,&avnx[153] } ,
    {20,"intron" ,27,0.0,&avnx[154] } ,
    {20,"j-segment" ,28,0.0,&avnx[155] } ,
    {20,"ltr" ,29,0.0,&avnx[156] } ,
    {20,"mat-peptide" ,30,0.0,&avnx[157] } ,
    {20,"misc-binding" ,31,0.0,&avnx[158] } ,
    {20,"misc-difference" ,32,0.0,&avnx[159] } ,
    {20,"misc-feature" ,33,0.0,&avnx[160] } ,
    {20,"misc-recomb" ,34,0.0,&avnx[161] } ,
    {20,"misc-RNA" ,35,0.0,&avnx[162] } ,
    {20,"misc-signal" ,36,0.0,&avnx[163] } ,
    {20,"misc-structure" ,37,0.0,&avnx[164] } ,
    {20,"modified-base" ,38,0.0,&avnx[165] } ,
    {20,"mutation" ,39,0.0,&avnx[166] } ,
    {20,"n-region" ,40,0.0,&avnx[167] } ,
    {20,"old-sequence" ,41,0.0,&avnx[168] } ,
    {20,"polyA-signal" ,42,0.0,&avnx[169] } ,
    {20,"polyA-site" ,43,0.0,&avnx[170] } ,
    {20,"precursor-RNA" ,44,0.0,&avnx[171] } ,
    {20,"prim-transcript" ,45,0.0,&avnx[172] } ,
    {20,"primer-bind" ,46,0.0,&avnx[173] } ,
    {20,"promoter" ,47,0.0,&avnx[174] } ,
    {20,"protein-bind" ,48,0.0,&avnx[175] } ,
    {20,"rbs" ,49,0.0,&avnx[176] } ,
    {20,"repeat-region" ,50,0.0,&avnx[177] } ,
    {20,"rep-origin" ,51,0.0,&avnx[178] } ,
    {20,"s-region" ,52,0.0,&avnx[179] } ,
    {20,"sig-peptide" ,53,0.0,&avnx[180] } ,
    {20,"source" ,54,0.0,&avnx[181] } ,
    {20,"stem-loop" ,55,0.0,&avnx[182] } ,
    {20,"sts" ,56,0.0,&avnx[183] } ,
    {20,"tata-signal" ,57,0.0,&avnx[184] } ,
    {20,"terminator" ,58,0.0,&avnx[185] } ,
    {20,"transit-peptide" ,59,0.0,&avnx[186] } ,
    {20,"unsure" ,60,0.0,&avnx[187] } ,
    {20,"v-region" ,61,0.0,&avnx[188] } ,
    {20,"v-segment" ,62,0.0,&avnx[189] } ,
    {20,"variation" ,63,0.0,&avnx[190] } ,
    {20,"virion" ,64,0.0,&avnx[191] } ,
    {20,"n3clip" ,65,0.0,&avnx[192] } ,
    {20,"n3UTR" ,66,0.0,&avnx[193] } ,
    {20,"n5clip" ,67,0.0,&avnx[194] } ,
    {20,"n5UTR" ,68,0.0,&avnx[195] } ,
    {20,"n10-signal" ,69,0.0,&avnx[196] } ,
    {20,"n35-signal" ,70,0.0,&avnx[197] } ,
    {20,"site-ref" ,71,0.0,&avnx[198] } ,
    {20,"region" ,72,0.0,&avnx[199] } ,
    {20,"comment" ,73,0.0,&avnx[200] } ,
    {20,"bond" ,74,0.0,&avnx[201] } ,
    {20,"site" ,75,0.0,&avnx[202] } ,
    {20,"rsite" ,76,0.0,&avnx[203] } ,
    {20,"user" ,77,0.0,&avnx[204] } ,
    {20,"txinit" ,78,0.0,&avnx[205] } ,
    {20,"num" ,79,0.0,&avnx[206] } ,
    {20,"psec-str" ,80,0.0,&avnx[207] } ,
    {20,"non-std-residue" ,81,0.0,&avnx[208] } ,
    {20,"het" ,82,0.0,&avnx[209] } ,
    {20,"biosrc" ,83,0.0,&avnx[210] } ,
    {20,"preprotein" ,84,0.0,&avnx[211] } ,
    {20,"mat-peptide-aa" ,85,0.0,&avnx[212] } ,
    {20,"sig-peptide-aa" ,86,0.0,&avnx[213] } ,
    {20,"transit-peptide-aa" ,87,0.0,&avnx[214] } ,
    {20,"snoRNA" ,88,0.0,&avnx[215] } ,
    {20,"gap" ,89,0.0,&avnx[216] } ,
    {20,"operon" ,90,0.0,&avnx[217] } ,
    {20,"oriT" ,91,0.0,&avnx[218] } ,
    {20,"ncRNA" ,92,0.0,&avnx[219] } ,
    {20,"tmRNA" ,93,0.0,NULL } ,
    {20,"allele" ,1,0.0,&avnx[221] } ,
    {20,"activity" ,2,0.0,&avnx[222] } ,
    {20,"anticodon" ,3,0.0,&avnx[223] } ,
    {20,"bound-moiety" ,4,0.0,&avnx[224] } ,
    {20,"chromosome" ,5,0.0,&avnx[225] } ,
    {20,"citation" ,6,0.0,&avnx[226] } ,
    {20,"codon" ,7,0.0,&avnx[227] } ,
    {20,"codon-start" ,8,0.0,&avnx[228] } ,
    {20,"codons-recognized" ,9,0.0,&avnx[229] } ,
    {20,"compare" ,10,0.0,&avnx[230] } ,
    {20,"cons-splice" ,11,0.0,&avnx[231] } ,
    {20,"db-xref" ,12,0.0,&avnx[232] } ,
    {20,"description" ,13,0.0,&avnx[233] } ,
    {20,"direction" ,14,0.0,&avnx[234] } ,
    {20,"ec-number" ,15,0.0,&avnx[235] } ,
    {20,"environmental-sample" ,16,0.0,&avnx[236] } ,
    {20,"evidence" ,17,0.0,&avnx[237] } ,
    {20,"exception" ,18,0.0,&avnx[238] } ,
    {20,"experiment" ,19,0.0,&avnx[239] } ,
    {20,"focus" ,20,0.0,&avnx[240] } ,
    {20,"frequency" ,21,0.0,&avnx[241] } ,
    {20,"function" ,22,0.0,&avnx[242] } ,
    {20,"gene" ,23,0.0,&avnx[243] } ,
    {20,"gene-description" ,24,0.0,&avnx[244] } ,
    {20,"inference" ,25,0.0,&avnx[245] } ,
    {20,"label" ,26,0.0,&avnx[246] } ,
    {20,"locus-tag" ,27,0.0,&avnx[247] } ,
    {20,"map" ,28,0.0,&avnx[248] } ,
    {20,"mobile-element" ,29,0.0,&avnx[249] } ,
    {20,"mod-base" ,30,0.0,&avnx[250] } ,
    {20,"mol-type" ,31,0.0,&avnx[251] } ,
    {20,"ncRNA-class" ,32,0.0,&avnx[252] } ,
    {20,"note" ,33,0.0,&avnx[253] } ,
    {20,"number" ,34,0.0,&avnx[254] } ,
    {20,"old-locus-tag" ,35,0.0,&avnx[255] } ,
    {20,"operon" ,36,0.0,&avnx[256] } ,
    {20,"organism" ,37,0.0,&avnx[257] } ,
    {20,"organelle" ,38,0.0,&avnx[258] } ,
    {20,"partial" ,39,0.0,&avnx[259] } ,
    {20,"phenotype" ,40,0.0,&avnx[260] } ,
    {20,"plasmid" ,41,0.0,&avnx[261] } ,
    {20,"product" ,42,0.0,&avnx[262] } ,
    {20,"protein-id" ,43,0.0,&avnx[263] } ,
    {20,"pseudo" ,44,0.0,&avnx[264] } ,
    {20,"rearranged" ,45,0.0,&avnx[265] } ,
    {20,"replace" ,46,0.0,&avnx[266] } ,
    {20,"rpt-family" ,47,0.0,&avnx[267] } ,
    {20,"rpt-type" ,48,0.0,&avnx[268] } ,
    {20,"rpt-unit" ,49,0.0,&avnx[269] } ,
    {20,"rpt-unit-seq" ,50,0.0,&avnx[270] } ,
    {20,"rpt-unit-range" ,51,0.0,&avnx[271] } ,
    {20,"segment" ,52,0.0,&avnx[272] } ,
    {20,"sequenced-mol" ,53,0.0,&avnx[273] } ,
    {20,"standard-name" ,54,0.0,&avnx[274] } ,
    {20,"synonym" ,55,0.0,&avnx[275] } ,
    {20,"transcript-id" ,56,0.0,&avnx[276] } ,
    {20,"transgenic" ,57,0.0,&avnx[277] } ,
    {20,"translation" ,58,0.0,&avnx[278] } ,
    {20,"transl-except" ,59,0.0,&avnx[279] } ,
    {20,"transl-table" ,60,0.0,&avnx[280] } ,
    {20,"usedin" ,61,0.0,&avnx[281] } ,
    {20,"mobile-element-type" ,62,0.0,&avnx[282] } ,
    {20,"mobile-element-name" ,63,0.0,&avnx[283] } ,
    {20,"gene-comment" ,64,0.0,&avnx[284] } ,
    {20,"satellite" ,65,0.0,&avnx[285] } ,
    {20,"satellite-type" ,66,0.0,&avnx[286] } ,
    {20,"satellite-name" ,67,0.0,NULL } ,
    {3,NULL,1,0.0,NULL } ,
    {20,"contains" ,1,0.0,&avnx[289] } ,
    {20,"equals" ,2,0.0,&avnx[290] } ,
    {20,"starts" ,3,0.0,&avnx[291] } ,
    {20,"ends" ,4,0.0,&avnx[292] } ,
    {20,"inlist" ,5,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {20,"product" ,1,0.0,&avnx[297] } ,
    {20,"comment" ,2,0.0,&avnx[298] } ,
    {20,"codons-recognized" ,3,0.0,&avnx[299] } ,
    {20,"ncrna-class" ,4,0.0,&avnx[300] } ,
    {20,"anticodon" ,5,0.0,&avnx[301] } ,
    {20,"transcript-id" ,6,0.0,&avnx[302] } ,
    {20,"gene-locus" ,7,0.0,&avnx[303] } ,
    {20,"gene-description" ,8,0.0,&avnx[304] } ,
    {20,"gene-maploc" ,9,0.0,&avnx[305] } ,
    {20,"gene-locus-tag" ,10,0.0,&avnx[306] } ,
    {20,"gene-synonym" ,11,0.0,&avnx[307] } ,
    {20,"gene-comment" ,12,0.0,NULL } ,
    {20,"cds-comment" ,1,0.0,&avnx[309] } ,
    {20,"gene-locus" ,2,0.0,&avnx[310] } ,
    {20,"gene-description" ,3,0.0,&avnx[311] } ,
    {20,"gene-comment" ,4,0.0,&avnx[312] } ,
    {20,"gene-allele" ,5,0.0,&avnx[313] } ,
    {20,"gene-maploc" ,6,0.0,&avnx[314] } ,
    {20,"gene-locus-tag" ,7,0.0,&avnx[315] } ,
    {20,"gene-synonym" ,8,0.0,&avnx[316] } ,
    {20,"gene-old-locus-tag" ,9,0.0,&avnx[317] } ,
    {20,"mrna-product" ,10,0.0,&avnx[318] } ,
    {20,"mrna-comment" ,11,0.0,&avnx[319] } ,
    {20,"prot-name" ,12,0.0,&avnx[320] } ,
    {20,"prot-description" ,13,0.0,&avnx[321] } ,
    {20,"prot-ec-number" ,14,0.0,&avnx[322] } ,
    {20,"prot-activity" ,15,0.0,&avnx[323] } ,
    {20,"prot-comment" ,16,0.0,&avnx[324] } ,
    {20,"mat-peptide-name" ,17,0.0,&avnx[325] } ,
    {20,"mat-peptide-description" ,18,0.0,&avnx[326] } ,
    {20,"mat-peptide-ec-number" ,19,0.0,&avnx[327] } ,
    {20,"mat-peptide-activity" ,20,0.0,&avnx[328] } ,
    {20,"mat-peptide-comment" ,21,0.0,&avnx[329] } ,
    {20,"cds-inference" ,22,0.0,&avnx[330] } ,
    {20,"gene-inference" ,23,0.0,&avnx[331] } ,
    {20,"codon-start" ,24,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[333] } ,
    {20,"genomic" ,1,0.0,&avnx[334] } ,
    {20,"precursor-RNA" ,2,0.0,&avnx[335] } ,
    {20,"mRNA" ,3,0.0,&avnx[336] } ,
    {20,"rRNA" ,4,0.0,&avnx[337] } ,
    {20,"tRNA" ,5,0.0,&avnx[338] } ,
    {20,"genomic-mRNA" ,6,0.0,&avnx[339] } ,
    {20,"cRNA" ,7,0.0,&avnx[340] } ,
    {20,"transcribed-RNA" ,8,0.0,&avnx[341] } ,
    {20,"ncRNA" ,9,0.0,&avnx[342] } ,
    {20,"transfer-messenger-RNA" ,10,0.0,&avnx[343] } ,
    {20,"other" ,11,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[345] } ,
    {20,"standard" ,1,0.0,&avnx[346] } ,
    {20,"est" ,2,0.0,&avnx[347] } ,
    {20,"sts" ,3,0.0,&avnx[348] } ,
    {20,"survey" ,4,0.0,&avnx[349] } ,
    {20,"genetic-map" ,5,0.0,&avnx[350] } ,
    {20,"physical-map" ,6,0.0,&avnx[351] } ,
    {20,"derived" ,7,0.0,&avnx[352] } ,
    {20,"concept-trans" ,8,0.0,&avnx[353] } ,
    {20,"seq-pept" ,9,0.0,&avnx[354] } ,
    {20,"both" ,10,0.0,&avnx[355] } ,
    {20,"seq-pept-overlap" ,11,0.0,&avnx[356] } ,
    {20,"seq-pept-homol" ,12,0.0,&avnx[357] } ,
    {20,"concept-trans-a" ,13,0.0,&avnx[358] } ,
    {20,"htgs-1" ,14,0.0,&avnx[359] } ,
    {20,"htgs-2" ,15,0.0,&avnx[360] } ,
    {20,"htgs-3" ,16,0.0,&avnx[361] } ,
    {20,"fli-cDNA" ,17,0.0,&avnx[362] } ,
    {20,"htgs-0" ,18,0.0,&avnx[363] } ,
    {20,"htc" ,19,0.0,&avnx[364] } ,
    {20,"wgs" ,20,0.0,&avnx[365] } ,
    {20,"barcode" ,21,0.0,&avnx[366] } ,
    {20,"composite-wgs-htgs" ,22,0.0,&avnx[367] } ,
    {20,"tsa" ,23,0.0,&avnx[368] } ,
    {20,"other" ,24,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[370] } ,
    {20,"complete" ,1,0.0,&avnx[371] } ,
    {20,"partial" ,2,0.0,&avnx[372] } ,
    {20,"no-left" ,3,0.0,&avnx[373] } ,
    {20,"no-right" ,4,0.0,&avnx[374] } ,
    {20,"no-ends" ,5,0.0,&avnx[375] } ,
    {20,"has-left" ,6,0.0,&avnx[376] } ,
    {20,"has-right" ,7,0.0,&avnx[377] } ,
    {20,"other" ,6,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[379] } ,
    {20,"dna" ,1,0.0,&avnx[380] } ,
    {20,"rna" ,2,0.0,&avnx[381] } ,
    {20,"protein" ,3,0.0,&avnx[382] } ,
    {20,"nucleotide" ,4,0.0,&avnx[383] } ,
    {20,"other" ,5,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[385] } ,
    {20,"linear" ,1,0.0,&avnx[386] } ,
    {20,"circular" ,2,0.0,&avnx[387] } ,
    {20,"tandem" ,3,0.0,&avnx[388] } ,
    {20,"other" ,4,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[390] } ,
    {20,"single" ,1,0.0,&avnx[391] } ,
    {20,"double" ,2,0.0,&avnx[392] } ,
    {20,"mixed" ,3,0.0,&avnx[393] } ,
    {20,"mixed-rev" ,4,0.0,&avnx[394] } ,
    {20,"other" ,5,0.0,NULL } ,
    {20,"cit" ,1,0.0,&avnx[396] } ,
    {20,"authors" ,2,0.0,&avnx[397] } ,
    {20,"journal" ,3,0.0,&avnx[398] } ,
    {20,"volume" ,4,0.0,&avnx[399] } ,
    {20,"issue" ,5,0.0,&avnx[400] } ,
    {20,"pages" ,6,0.0,&avnx[401] } ,
    {20,"date" ,7,0.0,&avnx[402] } ,
    {20,"serial-number" ,8,0.0,&avnx[403] } ,
    {20,"title" ,9,0.0,&avnx[404] } ,
    {20,"affiliation" ,10,0.0,&avnx[405] } ,
    {20,"affil-div" ,11,0.0,&avnx[406] } ,
    {20,"affil-city" ,12,0.0,&avnx[407] } ,
    {20,"affil-sub" ,13,0.0,&avnx[408] } ,
    {20,"affil-country" ,14,0.0,&avnx[409] } ,
    {20,"affil-street" ,15,0.0,&avnx[410] } ,
    {20,"affil-email" ,16,0.0,&avnx[411] } ,
    {20,"affil-fax" ,17,0.0,&avnx[412] } ,
    {20,"affil-phone" ,18,0.0,&avnx[413] } ,
    {20,"affil-zipcode" ,19,0.0,&avnx[414] } ,
    {20,"authors-initials" ,20,0.0,NULL } ,
    {20,"genome-project-id" ,1,0.0,&avnx[416] } ,
    {20,"comment-descriptor" ,2,0.0,&avnx[417] } ,
    {20,"defline" ,3,0.0,&avnx[418] } ,
    {20,"keyword" ,4,0.0,NULL } ,
    {20,"replace-old" ,1,0.0,&avnx[420] } ,
    {20,"append-semi" ,2,0.0,&avnx[421] } ,
    {20,"append-space" ,3,0.0,&avnx[422] } ,
    {20,"append-colon" ,4,0.0,&avnx[423] } ,
    {20,"append-comma" ,5,0.0,&avnx[424] } ,
    {20,"append-none" ,6,0.0,&avnx[425] } ,
    {20,"prefix-semi" ,7,0.0,&avnx[426] } ,
    {20,"prefix-space" ,8,0.0,&avnx[427] } ,
    {20,"prefix-colon" ,9,0.0,&avnx[428] } ,
    {20,"prefix-comma" ,10,0.0,&avnx[429] } ,
    {20,"prefix-none" ,11,0.0,&avnx[430] } ,
    {20,"leave-old" ,12,0.0,&avnx[431] } ,
    {20,"add-qual" ,13,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"anywhere" ,0,0.0,&avnx[434] } ,
    {20,"beginning" ,1,0.0,&avnx[435] } ,
    {20,"end" ,2,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"any" ,0,0.0,&avnx[446] } ,
    {20,"plus" ,1,0.0,&avnx[447] } ,
    {20,"minus" ,2,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"any" ,0,0.0,&avnx[450] } ,
    {20,"nuc" ,1,0.0,&avnx[451] } ,
    {20,"prot" ,2,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"either" ,0,0.0,&avnx[454] } ,
    {20,"partial" ,1,0.0,&avnx[455] } ,
    {20,"complete" ,2,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"any" ,0,0.0,&avnx[458] } ,
    {20,"feature" ,1,0.0,&avnx[459] } ,
    {20,"descriptor" ,2,0.0,NULL } ,
    {20,"gene" ,1,0.0,&avnx[461] } ,
    {20,"mRNA" ,2,0.0,&avnx[462] } ,
    {20,"cds" ,3,0.0,&avnx[463] } ,
    {20,"prot" ,4,0.0,&avnx[464] } ,
    {20,"exon" ,5,0.0,&avnx[465] } ,
    {20,"mat-peptide" ,6,0.0,NULL } ,
    {2,NULL,1,0.0,NULL } ,
    {20,"any" ,0,0.0,&avnx[468] } ,
    {20,"genomic" ,1,0.0,&avnx[469] } ,
    {20,"precursor-RNA" ,2,0.0,&avnx[470] } ,
    {20,"mRNA" ,3,0.0,&avnx[471] } ,
    {20,"rRNA" ,4,0.0,&avnx[472] } ,
    {20,"tRNA" ,5,0.0,&avnx[473] } ,
    {20,"genomic-mRNA" ,6,0.0,&avnx[474] } ,
    {20,"cRNA" ,7,0.0,&avnx[475] } ,
    {20,"transcribed-RNA" ,8,0.0,&avnx[476] } ,
    {20,"ncRNA" ,9,0.0,&avnx[477] } ,
    {20,"transfer-messenger-RNA" ,10,0.0,NULL } ,
    {20,"any" ,0,0.0,&avnx[479] } ,
    {20,"published" ,1,0.0,&avnx[480] } ,
    {20,"unpublished" ,2,0.0,&avnx[481] } ,
    {20,"in-press" ,3,0.0,&avnx[482] } ,
    {20,"submitter-block" ,4,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"none" ,0,0.0,&avnx[487] } ,
    {20,"tolower" ,1,0.0,&avnx[488] } ,
    {20,"toupper" ,2,0.0,&avnx[489] } ,
    {20,"firstcap" ,3,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,1,0.0,NULL } ,
    {2,NULL,1,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {3,NULL,-1,0.0,NULL } ,
    {20,"disulfide" ,1,0.0,&avnx[499] } ,
    {20,"thioester" ,2,0.0,&avnx[500] } ,
    {20,"crosslink" ,3,0.0,&avnx[501] } ,
    {20,"thioether" ,4,0.0,&avnx[502] } ,
    {20,"other" ,5,0.0,NULL } ,
    {20,"active" ,1,0.0,&avnx[504] } ,
    {20,"binding" ,2,0.0,&avnx[505] } ,
    {20,"cleavage" ,3,0.0,&avnx[506] } ,
    {20,"inhibit" ,4,0.0,&avnx[507] } ,
    {20,"modified" ,5,0.0,&avnx[508] } ,
    {20,"glycosylation" ,6,0.0,&avnx[509] } ,
    {20,"myristoylation" ,7,0.0,&avnx[510] } ,
    {20,"mutagenized" ,8,0.0,&avnx[511] } ,
    {20,"metal-binding" ,9,0.0,&avnx[512] } ,
    {20,"phosphorylation" ,10,0.0,&avnx[513] } ,
    {20,"acetylation" ,11,0.0,&avnx[514] } ,
    {20,"amidation" ,12,0.0,&avnx[515] } ,
    {20,"methylation" ,13,0.0,&avnx[516] } ,
    {20,"hydroxylation" ,14,0.0,&avnx[517] } ,
    {20,"sulfatation" ,15,0.0,&avnx[518] } ,
    {20,"oxidative-deamination" ,16,0.0,&avnx[519] } ,
    {20,"pyrrolidone-carboxylic-acid" ,17,0.0,&avnx[520] } ,
    {20,"gamma-carboxyglutamic-acid" ,18,0.0,&avnx[521] } ,
    {20,"blocked" ,19,0.0,&avnx[522] } ,
    {20,"lipid-binding" ,20,0.0,&avnx[523] } ,
    {20,"np-binding" ,21,0.0,&avnx[524] } ,
    {20,"dna-binding" ,22,0.0,&avnx[525] } ,
    {20,"signal-peptide" ,23,0.0,&avnx[526] } ,
    {20,"transit-peptide" ,24,0.0,&avnx[527] } ,
    {20,"transmembrane-region" ,25,0.0,&avnx[528] } ,
    {20,"nitrosylation" ,26,0.0,&avnx[529] } ,
    {20,"other" ,27,0.0,NULL } ,
    {20,"any" ,0,0.0,&avnx[531] } ,
    {20,"plus" ,1,0.0,&avnx[532] } ,
    {20,"minus" ,2,0.0,&avnx[533] } ,
    {20,"unknown" ,3,0.0,&avnx[534] } ,
    {20,"both" ,4,0.0,NULL } ,
    {20,"plus" ,1,0.0,&avnx[536] } ,
    {20,"minus" ,2,0.0,&avnx[537] } ,
    {20,"unknown" ,3,0.0,&avnx[538] } ,
    {20,"both" ,4,0.0,&avnx[539] } ,
    {20,"reverse" ,5,0.0,NULL } ,
    {20,"all" ,0,0.0,&avnx[541] } ,
    {20,"at-end" ,1,0.0,&avnx[542] } ,
    {20,"bad-start" ,2,0.0,&avnx[543] } ,
    {20,"frame-not-one" ,3,0.0,NULL } ,
    {20,"all" ,0,0.0,&avnx[545] } ,
    {20,"not-at-end" ,1,0.0,&avnx[546] } ,
    {20,"good-start" ,2,0.0,NULL } ,
    {20,"all" ,0,0.0,&avnx[548] } ,
    {20,"at-end" ,1,0.0,&avnx[549] } ,
    {20,"bad-end" ,2,0.0,NULL } ,
    {20,"all" ,0,0.0,&avnx[551] } ,
    {20,"not-at-end" ,1,0.0,&avnx[552] } ,
    {20,"good-end" ,2,0.0,NULL } ,
    {20,"join" ,1,0.0,&avnx[554] } ,
    {20,"order" ,2,0.0,&avnx[555] } ,
    {20,"merge" ,3,0.0,NULL } ,
    {20,"all" ,0,0.0,&avnx[557] } ,
    {20,"title" ,1,0.0,&avnx[558] } ,
    {20,"source" ,2,0.0,&avnx[559] } ,
    {20,"publication" ,3,0.0,&avnx[560] } ,
    {20,"comment" ,4,0.0,&avnx[561] } ,
    {20,"genbank" ,5,0.0,&avnx[562] } ,
    {20,"user" ,6,0.0,&avnx[563] } ,
    {20,"create-date" ,7,0.0,&avnx[564] } ,
    {20,"update-date" ,8,0.0,&avnx[565] } ,
    {20,"mol-info" ,9,0.0,&avnx[566] } ,
    {20,"structured-comment" ,10,0.0,&avnx[567] } ,
    {20,"genome-project-id" ,11,0.0,NULL } ,
    {20,"feature-list" ,1,0.0,&avnx[569] } ,
    {20,"complete-sequence" ,2,0.0,&avnx[570] } ,
    {20,"complete-genome" ,3,0.0,NULL } };

static AsnType atx[387] = {
  {401, "AECR-action" ,1,0,0,0,0,1,0,0,NULL,&atx[38],&atx[1],0,&atx[231]} ,
  {0, "action" ,128,0,0,0,0,0,0,0,NULL,&atx[2],NULL,0,&atx[172]} ,
  {480, "Action-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[3],0,&atx[263]} ,
  {0, "apply" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[81]} ,
  {473, "Apply-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[5],0,&atx[82]} ,
  {0, "field" ,128,0,0,0,0,0,0,0,NULL,&atx[6],NULL,0,&atx[78]} ,
  {462, "Field-type" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[7],0,&atx[218]} ,
  {0, "source-qual" ,128,0,0,0,0,0,0,0,NULL,&atx[8],NULL,0,&atx[20]} ,
  {428, "Source-qual-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[9],0,&atx[307]} ,
  {0, "textqual" ,128,0,0,0,0,0,0,0,NULL,&atx[10],NULL,0,&atx[12]} ,
  {424, "Source-qual" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[0],0,&atx[95]} ,
  {310, "ENUMERATED" ,0,10,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "location" ,128,1,0,0,0,0,0,0,NULL,&atx[13],NULL,0,&atx[14]} ,
  {426, "Source-location" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[96],0,&atx[15]} ,
  {0, "origin" ,128,2,0,0,0,0,0,0,NULL,&atx[15],NULL,0,&atx[16]} ,
  {427, "Source-origin" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[119],0,&atx[8]} ,
  {0, "gcode" ,128,3,0,0,0,0,0,0,NULL,&atx[17],NULL,0,&atx[18]} ,
  {302, "INTEGER" ,0,2,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "mgcode" ,128,4,0,0,0,0,0,0,NULL,&atx[17],NULL,0,NULL} ,
  {315, "CHOICE" ,0,-1,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "feature-field" ,128,1,0,0,0,0,0,0,NULL,&atx[21],NULL,0,&atx[39]} ,
  {417, "Feature-field" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[22],0,&atx[257]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[23],NULL,0,&atx[24]} ,
  {411, "Feature-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[126],0,&atx[27]} ,
  {0, "field" ,128,1,0,0,0,0,0,0,NULL,&atx[25],NULL,0,NULL} ,
  {416, "Feat-qual-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[26],0,&atx[21]} ,
  {0, "legal-qual" ,128,0,0,0,0,0,0,0,NULL,&atx[27],NULL,0,&atx[28]} ,
  {412, "Feat-qual-legal" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[220],0,&atx[299]} ,
  {0, "illegal-qual" ,128,1,0,0,0,0,0,0,NULL,&atx[29],NULL,0,NULL} ,
  {405, "String-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[30],0,&atx[181]} ,
  {0, "match-text" ,128,0,0,0,0,0,0,0,NULL,&atx[31],NULL,0,&atx[32]} ,
  {323, "VisibleString" ,0,26,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "match-location" ,128,1,0,0,1,0,0,0,&avnx[287],&atx[33],NULL,0,&atx[34]} ,
  {404, "String-location" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[288],0,&atx[29]} ,
  {0, "case-sensitive" ,128,2,0,0,1,0,0,0,&avnx[293],&atx[35],NULL,0,&atx[36]} ,
  {301, "BOOLEAN" ,0,1,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "whole-word" ,128,3,0,0,1,0,0,0,&avnx[294],&atx[35],NULL,0,&atx[37]} ,
  {0, "not-present" ,128,4,0,0,1,0,0,0,&avnx[295],&atx[35],NULL,0,NULL} ,
  {311, "SEQUENCE" ,0,16,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "rna-field" ,128,2,0,0,0,0,0,0,NULL,&atx[40],NULL,0,&atx[53]} ,
  {422, "Rna-qual" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[41],0,&atx[104]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[42],NULL,0,&atx[51]} ,
  {420, "Rna-feat-type" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[43],0,&atx[52]} ,
  {0, "preRNA" ,128,0,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[45]} ,
  {305, "NULL" ,0,5,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "mRNA" ,128,1,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[46]} ,
  {0, "tRNA" ,128,2,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[47]} ,
  {0, "rRNA" ,128,3,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[48]} ,
  {0, "ncRNA" ,128,4,0,0,0,0,0,0,NULL,&atx[31],NULL,0,&atx[49]} ,
  {0, "tmRNA" ,128,5,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[50]} ,
  {0, "miscRNA" ,128,6,0,0,0,0,0,0,NULL,&atx[44],NULL,0,NULL} ,
  {0, "field" ,128,1,0,0,0,0,0,0,NULL,&atx[52],NULL,0,NULL} ,
  {421, "Rna-field" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[296],0,&atx[40]} ,
  {0, "cds-gene-prot" ,128,3,0,0,0,0,0,0,NULL,&atx[54],NULL,0,&atx[55]} ,
  {432, "CDSGeneProt-field" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[308],0,&atx[109]} ,
  {0, "molinfo-field" ,128,4,0,0,0,0,0,0,NULL,&atx[56],NULL,0,&atx[69]} ,
  {440, "Molinfo-field" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[57],0,&atx[115]} ,
  {0, "molecule" ,128,0,0,0,0,0,0,0,NULL,&atx[58],NULL,0,&atx[59]} ,
  {434, "Molecule-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[332],0,&atx[60]} ,
  {0, "technique" ,128,1,0,0,0,0,0,0,NULL,&atx[60],NULL,0,&atx[61]} ,
  {435, "Technique-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[344],0,&atx[62]} ,
  {0, "completedness" ,128,2,0,0,0,0,0,0,NULL,&atx[62],NULL,0,&atx[63]} ,
  {436, "Completedness-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[369],0,&atx[64]} ,
  {0, "mol-class" ,128,3,0,0,0,0,0,0,NULL,&atx[64],NULL,0,&atx[65]} ,
  {437, "Molecule-class-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[378],0,&atx[66]} ,
  {0, "topology" ,128,4,0,0,0,0,0,0,NULL,&atx[66],NULL,0,&atx[67]} ,
  {438, "Topology-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[384],0,&atx[68]} ,
  {0, "strand" ,128,5,0,0,0,0,0,0,NULL,&atx[68],NULL,0,NULL} ,
  {439, "Strand-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[389],0,&atx[56]} ,
  {0, "pub" ,128,5,0,0,0,0,0,0,NULL,&atx[70],NULL,0,&atx[71]} ,
  {449, "Publication-field" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[395],0,&atx[72]} ,
  {0, "struc-comment-field" ,128,6,0,0,0,0,0,0,NULL,&atx[72],NULL,0,&atx[76]} ,
  {450, "Structured-comment-field" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[73],0,&atx[139]} ,
  {0, "database" ,128,0,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[74]} ,
  {0, "named" ,128,1,0,0,0,0,0,0,NULL,&atx[31],NULL,0,&atx[75]} ,
  {0, "field-name" ,128,2,0,0,0,0,0,0,NULL,&atx[44],NULL,0,NULL} ,
  {0, "misc" ,128,7,0,0,0,0,0,0,NULL,&atx[77],NULL,0,NULL} ,
  {452, "Misc-field" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[415],0,&atx[225]} ,
  {0, "value" ,128,1,0,0,0,0,0,0,NULL,&atx[31],NULL,0,&atx[79]} ,
  {0, "existing-text" ,128,2,0,0,0,0,0,0,NULL,&atx[80],NULL,0,NULL} ,
  {472, "ExistingTextOption" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[419],0,&atx[4]} ,
  {0, "edit" ,128,1,0,0,0,0,0,0,NULL,&atx[82],NULL,0,&atx[90]} ,
  {474, "Edit-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[83],0,&atx[91]} ,
  {0, "edit" ,128,0,0,0,0,0,0,0,NULL,&atx[84],NULL,0,&atx[89]} ,
  {470, "Field-edit" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[85],0,&atx[93]} ,
  {0, "find-txt" ,128,0,0,0,0,0,0,0,NULL,&atx[31],NULL,0,&atx[86]} ,
  {0, "repl-txt" ,128,1,0,1,0,0,0,0,NULL,&atx[31],NULL,0,&atx[87]} ,
  {0, "location" ,128,2,0,0,1,0,0,0,&avnx[432],&atx[88],NULL,0,NULL} ,
  {469, "Field-edit-location" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[433],0,&atx[84]} ,
  {0, "field" ,128,1,0,0,0,0,0,0,NULL,&atx[6],NULL,0,NULL} ,
  {0, "convert" ,128,2,0,0,0,0,0,0,NULL,&atx[91],NULL,0,&atx[145]} ,
  {475, "Convert-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[92],0,&atx[146]} ,
  {0, "fields" ,128,0,0,0,0,0,0,0,NULL,&atx[93],NULL,0,&atx[142]} ,
  {471, "Field-pair-type" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[94],0,&atx[80]} ,
  {0, "source-qual" ,128,0,0,0,0,0,0,0,NULL,&atx[95],NULL,0,&atx[98]} ,
  {425, "Source-qual-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[96],0,&atx[13]} ,
  {0, "field-from" ,128,0,0,0,0,0,0,0,NULL,&atx[10],NULL,0,&atx[97]} ,
  {0, "field-to" ,128,1,0,0,0,0,0,0,NULL,&atx[10],NULL,0,NULL} ,
  {0, "feature-field" ,128,1,0,0,0,0,0,0,NULL,&atx[99],NULL,0,&atx[103]} ,
  {419, "Feature-field-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[100],0,&atx[42]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[23],NULL,0,&atx[101]} ,
  {0, "field-from" ,128,1,0,0,0,0,0,0,NULL,&atx[25],NULL,0,&atx[102]} ,
  {0, "field-to" ,128,2,0,0,0,0,0,0,NULL,&atx[25],NULL,0,NULL} ,
  {0, "rna-field" ,128,2,0,0,0,0,0,0,NULL,&atx[104],NULL,0,&atx[108]} ,
  {423, "Rna-qual-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[105],0,&atx[10]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[42],NULL,0,&atx[106]} ,
  {0, "field-from" ,128,1,0,0,0,0,0,0,NULL,&atx[52],NULL,0,&atx[107]} ,
  {0, "field-to" ,128,2,0,0,0,0,0,0,NULL,&atx[52],NULL,0,NULL} ,
  {0, "cds-gene-prot" ,128,3,0,0,0,0,0,0,NULL,&atx[109],NULL,0,&atx[112]} ,
  {433, "CDSGeneProt-field-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[110],0,&atx[58]} ,
  {0, "field-from" ,128,0,0,0,0,0,0,0,NULL,&atx[54],NULL,0,&atx[111]} ,
  {0, "field-to" ,128,1,0,0,0,0,0,0,NULL,&atx[54],NULL,0,NULL} ,
  {0, "molinfo-field" ,128,4,0,0,0,0,0,0,NULL,&atx[113],NULL,0,&atx[138]} ,
  {447, "Molinfo-field-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[114],0,&atx[381]} ,
  {0, "molecule" ,128,0,0,0,0,0,0,0,NULL,&atx[115],NULL,0,&atx[118]} ,
  {441, "Molinfo-molecule-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[116],0,&atx[119]} ,
  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[58],NULL,0,&atx[117]} ,
  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[58],NULL,0,NULL} ,
  {0, "technique" ,128,1,0,0,0,0,0,0,NULL,&atx[119],NULL,0,&atx[122]} ,
  {442, "Molinfo-technique-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[120],0,&atx[123]} ,
  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[60],NULL,0,&atx[121]} ,
  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[60],NULL,0,NULL} ,
  {0, "completedness" ,128,2,0,0,0,0,0,0,NULL,&atx[123],NULL,0,&atx[126]} ,
  {443, "Molinfo-completedness-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[124],0,&atx[127]} ,
  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[62],NULL,0,&atx[125]} ,
  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[62],NULL,0,NULL} ,
  {0, "mol-class" ,128,3,0,0,0,0,0,0,NULL,&atx[127],NULL,0,&atx[130]} ,
  {444, "Molinfo-mol-class-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[128],0,&atx[131]} ,
  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[64],NULL,0,&atx[129]} ,
  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[64],NULL,0,NULL} ,
  {0, "topology" ,128,4,0,0,0,0,0,0,NULL,&atx[131],NULL,0,&atx[134]} ,
  {445, "Molinfo-topology-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[132],0,&atx[135]} ,
  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[66],NULL,0,&atx[133]} ,
  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[66],NULL,0,NULL} ,
  {0, "strand" ,128,5,0,0,0,0,0,0,NULL,&atx[135],NULL,0,NULL} ,
  {446, "Molinfo-strand-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[136],0,&atx[113]} ,
  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[68],NULL,0,&atx[137]} ,
  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[68],NULL,0,NULL} ,
  {0, "struc-comment-field" ,128,5,0,0,0,0,0,0,NULL,&atx[139],NULL,0,NULL} ,
  {451, "Structured-comment-field-pair" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[140],0,&atx[77]} ,
  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[72],NULL,0,&atx[141]} ,
  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[72],NULL,0,NULL} ,
  {0, "strip-name" ,128,1,0,0,1,0,0,0,&avnx[436],&atx[35],NULL,0,&atx[143]} ,
  {0, "keep-original" ,128,2,0,0,1,0,0,0,&avnx[437],&atx[35],NULL,0,&atx[144]} ,
  {0, "existing-text" ,128,3,0,0,0,0,0,0,NULL,&atx[80],NULL,0,NULL} ,
  {0, "copy" ,128,3,0,0,0,0,0,0,NULL,&atx[146],NULL,0,&atx[149]} ,
  {476, "Copy-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[147],0,&atx[150]} ,
  {0, "fields" ,128,0,0,0,0,0,0,0,NULL,&atx[93],NULL,0,&atx[148]} ,
  {0, "existing-text" ,128,1,0,0,0,0,0,0,NULL,&atx[80],NULL,0,NULL} ,
  {0, "swap" ,128,4,0,0,0,0,0,0,NULL,&atx[150],NULL,0,&atx[153]} ,
  {477, "Swap-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[151],0,&atx[157]} ,
  {0, "fields" ,128,0,0,0,0,0,0,0,NULL,&atx[93],NULL,0,&atx[152]} ,
  {0, "field-to" ,128,1,0,0,0,0,0,0,NULL,&atx[6],NULL,0,NULL} ,
  {0, "remove" ,128,5,0,0,0,0,0,0,NULL,&atx[154],NULL,0,&atx[156]} ,
  {479, "Remove-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[155],0,&atx[2]} ,
  {0, "field" ,128,0,0,0,0,0,0,0,NULL,&atx[6],NULL,0,NULL} ,
  {0, "parse" ,128,6,0,0,0,0,0,0,NULL,&atx[157],NULL,0,NULL} ,
  {478, "AECRParse-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[158],0,&atx[154]} ,
  {0, "portion" ,128,0,0,0,0,0,0,0,NULL,&atx[159],NULL,0,&atx[167]} ,
  {468, "Text-portion" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[160],0,&atx[88]} ,
  {0, "left-text" ,128,0,0,1,0,0,0,0,NULL,&atx[31],NULL,0,&atx[161]} ,
  {0, "include-left" ,128,1,0,0,0,0,0,0,NULL,&atx[35],NULL,0,&atx[162]} ,
  {0, "right-text" ,128,2,0,1,0,0,0,0,NULL,&atx[31],NULL,0,&atx[163]} ,
  {0, "include-right" ,128,3,0,0,0,0,0,0,NULL,&atx[35],NULL,0,&atx[164]} ,
  {0, "inside" ,128,4,0,0,0,0,0,0,NULL,&atx[35],NULL,0,&atx[165]} ,
  {0, "case-sensitive" ,128,5,0,0,1,0,0,0,&avnx[438],&atx[35],NULL,0,&atx[166]} ,
  {0, "whole-word" ,128,6,0,0,1,0,0,0,&avnx[439],&atx[35],NULL,0,NULL} ,
  {0, "fields" ,128,1,0,0,0,0,0,0,NULL,&atx[93],NULL,0,&atx[168]} ,
  {0, "remove-from-parsed" ,128,2,0,0,1,0,0,0,&avnx[440],&atx[35],NULL,0,&atx[169]} ,
  {0, "remove-left" ,128,3,0,0,1,0,0,0,&avnx[441],&atx[35],NULL,0,&atx[170]} ,
  {0, "remove-right" ,128,4,0,0,1,0,0,0,&avnx[442],&atx[35],NULL,0,&atx[171]} ,
  {0, "existing-text" ,128,5,0,0,0,0,0,0,NULL,&atx[80],NULL,0,NULL} ,
  {0, "also-change-mrna" ,128,1,0,0,1,0,0,0,&avnx[443],&atx[35],NULL,0,&atx[173]} ,
  {0, "constraint" ,128,2,0,1,0,0,0,0,NULL,&atx[174],NULL,0,NULL} ,
  {467, "Constraint-choice-set" ,1,0,0,0,0,0,0,0,NULL,&atx[230],&atx[175],0,&atx[159]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[176],NULL,0,NULL} ,
  {466, "Constraint-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[177],0,&atx[174]} ,
  {0, "string" ,128,0,0,0,0,0,0,0,NULL,&atx[29],NULL,0,&atx[178]} ,
  {0, "location" ,128,1,0,0,0,0,0,0,NULL,&atx[179],NULL,0,&atx[187]} ,
  {409, "Location-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[180],0,&atx[197]} ,
  {0, "strand" ,128,0,0,0,1,0,0,0,&avnx[444],&atx[181],NULL,0,&atx[182]} ,
  {406, "Strand-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[445],0,&atx[183]} ,
  {0, "seq-type" ,128,1,0,0,1,0,0,0,&avnx[448],&atx[183],NULL,0,&atx[184]} ,
  {407, "Seqtype-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[449],0,&atx[185]} ,
  {0, "partial5" ,128,2,0,0,1,0,0,0,&avnx[452],&atx[185],NULL,0,&atx[186]} ,
  {408, "Partial-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[453],0,&atx[179]} ,
  {0, "partial3" ,128,3,0,0,1,0,0,0,&avnx[456],&atx[185],NULL,0,NULL} ,
  {0, "field" ,128,2,0,0,0,0,0,0,NULL,&atx[188],NULL,0,&atx[191]} ,
  {461, "Field-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[189],0,&atx[6]} ,
  {0, "field" ,128,0,0,0,0,0,0,0,NULL,&atx[6],NULL,0,&atx[190]} ,
  {0, "string-constraint" ,128,1,0,0,0,0,0,0,NULL,&atx[29],NULL,0,NULL} ,
  {0, "source" ,128,3,0,0,0,0,0,0,NULL,&atx[192],NULL,0,&atx[198]} ,
  {456, "Source-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[193],0,&atx[208]} ,
  {0, "field1" ,128,0,0,1,0,0,0,0,NULL,&atx[8],NULL,0,&atx[194]} ,
  {0, "field2" ,128,1,0,1,0,0,0,0,NULL,&atx[8],NULL,0,&atx[195]} ,
  {0, "constraint" ,128,2,0,1,0,0,0,0,NULL,&atx[29],NULL,0,&atx[196]} ,
  {0, "type-constraint" ,128,3,0,1,0,0,0,0,NULL,&atx[197],NULL,0,NULL} ,
  {410, "Object-type-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[457],0,&atx[23]} ,
  {0, "cdsgeneprot-qual" ,128,4,0,0,0,0,0,0,NULL,&atx[199],NULL,0,&atx[205]} ,
  {460, "CDSGeneProt-qual-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[200],0,&atx[188]} ,
  {0, "field1" ,128,0,0,1,0,0,0,0,NULL,&atx[201],NULL,0,&atx[203]} ,
  {459, "CDSGeneProt-constraint-field" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[202],0,&atx[199]} ,
  {0, "field" ,128,0,0,0,0,0,0,0,NULL,&atx[54],NULL,0,NULL} ,
  {0, "field2" ,128,1,0,1,0,0,0,0,NULL,&atx[201],NULL,0,&atx[204]} ,
  {0, "constraint" ,128,2,0,1,0,0,0,0,NULL,&atx[29],NULL,0,NULL} ,
  {0, "cdsgeneprot-pseudo" ,128,5,0,0,0,0,0,0,NULL,&atx[206],NULL,0,&atx[210]} ,
  {458, "CDSGeneProt-pseudo-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[207],0,&atx[201]} ,
  {0, "feature" ,128,0,0,0,0,0,0,0,NULL,&atx[208],NULL,0,&atx[209]} ,
  {457, "CDSGeneProt-feature-type-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[460],0,&atx[206]} ,
  {0, "is-pseudo" ,128,1,0,0,1,0,0,0,&avnx[466],&atx[35],NULL,0,NULL} ,
  {0, "sequence" ,128,6,0,0,0,0,0,0,NULL,&atx[211],NULL,0,&atx[222]} ,
  {465, "Sequence-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[212],0,&atx[176]} ,
  {0, "seqtype" ,128,0,0,1,0,0,0,0,NULL,&atx[213],NULL,0,&atx[220]} ,
  {464, "Sequence-constraint-mol-type-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[214],0,&atx[211]} ,
  {0, "any" ,128,0,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[215]} ,
  {0, "nucleotide" ,128,1,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[216]} ,
  {0, "dna" ,128,2,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[217]} ,
  {0, "rna" ,128,3,0,0,0,0,0,0,NULL,&atx[218],NULL,0,&atx[219]} ,
  {463, "Sequence-constraint-rnamol" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[467],0,&atx[213]} ,
  {0, "protein" ,128,4,0,0,0,0,0,0,NULL,&atx[44],NULL,0,NULL} ,
  {0, "id" ,128,1,0,1,0,0,0,0,NULL,&atx[29],NULL,0,&atx[221]} ,
  {0, "feature" ,128,2,0,0,0,0,0,0,NULL,&atx[23],NULL,0,NULL} ,
  {0, "pub" ,128,7,0,0,0,0,0,0,NULL,&atx[223],NULL,0,NULL} ,
  {455, "Publication-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[224],0,&atx[192]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[225],NULL,0,&atx[226]} ,
  {453, "Pub-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[478],0,&atx[227]} ,
  {0, "field" ,128,1,0,1,0,0,0,0,NULL,&atx[227],NULL,0,NULL} ,
  {454, "Pub-field-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[228],0,&atx[223]} ,
  {0, "field" ,128,0,0,0,0,0,0,0,NULL,&atx[70],NULL,0,&atx[229]} ,
  {0, "constraint" ,128,1,0,0,0,0,0,0,NULL,&atx[29],NULL,0,NULL} ,
  {314, "SET OF" ,0,17,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {402, "Parse-action" ,1,0,0,0,0,1,0,0,NULL,&atx[38],&atx[232],0,&atx[266]} ,
  {0, "portion" ,128,0,0,0,0,0,0,0,NULL,&atx[159],NULL,0,&atx[233]} ,
  {0, "src" ,128,1,0,0,0,0,0,0,NULL,&atx[234],NULL,0,&atx[249]} ,
  {484, "Parse-src" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[235],0,&atx[253]} ,
  {0, "defline" ,128,0,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[236]} ,
  {0, "flatfile" ,128,1,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[237]} ,
  {0, "local-id" ,128,2,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[238]} ,
  {0, "org" ,128,3,0,0,0,0,0,0,NULL,&atx[239],NULL,0,&atx[245]} ,
  {483, "Parse-src-org" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[240],0,&atx[234]} ,
  {0, "field" ,128,0,0,0,0,0,0,0,NULL,&atx[241],NULL,0,&atx[244]} ,
  {482, "Parse-src-org-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[242],0,&atx[239]} ,
  {0, "source-qual" ,128,0,0,0,0,0,0,0,NULL,&atx[10],NULL,0,&atx[243]} ,
  {0, "taxname-after-binomial" ,128,1,0,0,0,0,0,0,NULL,&atx[44],NULL,0,NULL} ,
  {0, "type" ,128,1,0,0,1,0,0,0,&avnx[483],&atx[197],NULL,0,NULL} ,
  {0, "comment" ,128,4,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[246]} ,
  {0, "bankit-comment" ,128,5,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[247]} ,
  {0, "structured-comment" ,128,6,0,0,0,0,0,0,NULL,&atx[31],NULL,0,&atx[248]} ,
  {0, "file-id" ,128,7,0,0,0,0,0,0,NULL,&atx[44],NULL,0,NULL} ,
  {0, "dest" ,128,2,0,0,0,0,0,0,NULL,&atx[250],NULL,0,&atx[262]} ,
  {486, "Parse-dest" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[251],0,&atx[280]} ,
  {0, "defline" ,128,0,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[252]} ,
  {0, "org" ,128,1,0,0,0,0,0,0,NULL,&atx[253],NULL,0,&atx[256]} ,
  {485, "Parse-dst-org" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[254],0,&atx[250]} ,
  {0, "field" ,128,0,0,0,0,0,0,0,NULL,&atx[8],NULL,0,&atx[255]} ,
  {0, "type" ,128,1,0,0,1,0,0,0,&avnx[484],&atx[197],NULL,0,NULL} ,
  {0, "featqual" ,128,2,0,0,0,0,0,0,NULL,&atx[257],NULL,0,&atx[260]} ,
  {418, "Feature-field-legal" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[258],0,&atx[99]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[23],NULL,0,&atx[259]} ,
  {0, "field" ,128,1,0,0,0,0,0,0,NULL,&atx[27],NULL,0,NULL} ,
  {0, "comment-descriptor" ,128,3,0,0,0,0,0,0,NULL,&atx[44],NULL,0,&atx[261]} ,
  {0, "dbxref" ,128,4,0,0,0,0,0,0,NULL,&atx[31],NULL,0,NULL} ,
  {0, "capitalization" ,128,3,0,0,1,0,0,0,&avnx[485],&atx[263],NULL,0,&atx[264]} ,
  {481, "Cap-change" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[486],0,&atx[241]} ,
  {0, "remove-from-parsed" ,128,4,0,0,1,0,0,0,&avnx[490],&atx[35],NULL,0,&atx[265]} ,
  {0, "existing-text" ,128,5,0,0,0,0,0,0,NULL,&atx[80],NULL,0,NULL} ,
  {403, "Macro-action-list" ,1,0,0,0,0,1,0,0,NULL,&atx[230],&atx[267],0,&atx[33]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[268],NULL,0,NULL} ,
  {517, "Macro-action-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[269],0,NULL} ,
  {0, "aecr" ,128,0,0,0,0,0,0,0,NULL,&atx[0],NULL,0,&atx[270]} ,
  {0, "parse" ,128,1,0,0,0,0,0,0,NULL,&atx[231],NULL,0,&atx[271]} ,
  {0, "add-feature" ,128,2,0,0,0,0,0,0,NULL,&atx[272],NULL,0,&atx[314]} ,
  {491, "Apply-feature-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[273],0,&atx[315]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[23],NULL,0,&atx[274]} ,
  {0, "partial5" ,128,1,0,0,1,0,0,0,&avnx[491],&atx[35],NULL,0,&atx[275]} ,
  {0, "partial3" ,128,2,0,0,1,0,0,0,&avnx[492],&atx[35],NULL,0,&atx[276]} ,
  {0, "plus-strand" ,128,3,0,0,1,0,0,0,&avnx[493],&atx[35],NULL,0,&atx[277]} ,
  {0, "location" ,128,4,0,0,0,0,0,0,NULL,&atx[278],NULL,0,&atx[284]} ,
  {488, "Location-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[279],0,&atx[287]} ,
  {0, "interval" ,128,0,0,0,0,0,0,0,NULL,&atx[280],NULL,0,&atx[283]} ,
  {487, "Location-interval" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[281],0,&atx[278]} ,
  {0, "from" ,128,0,0,0,0,0,0,0,NULL,&atx[17],NULL,0,&atx[282]} ,
  {0, "to" ,128,1,0,0,0,0,0,0,NULL,&atx[17],NULL,0,NULL} ,
  {0, "whole-sequence" ,128,1,0,0,0,0,0,0,NULL,&atx[44],NULL,0,NULL} ,
  {0, "seq-list" ,128,5,0,0,0,0,0,0,NULL,&atx[285],NULL,0,&atx[290]} ,
  {490, "Sequence-list-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[286],0,&atx[272]} ,
  {0, "list" ,128,0,0,0,0,0,0,0,NULL,&atx[287],NULL,0,&atx[289]} ,
  {489, "Sequence-list" ,1,0,0,0,0,0,0,0,NULL,&atx[230],&atx[288],0,&atx[285]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[31],NULL,0,NULL} ,
  {0, "all" ,128,1,0,0,0,0,0,0,NULL,&atx[44],NULL,0,NULL} ,
  {0, "add-redundant" ,128,6,0,0,1,0,0,0,&avnx[494],&atx[35],NULL,0,&atx[291]} ,
  {0, "add-mrna" ,128,7,0,0,1,0,0,0,&avnx[495],&atx[35],NULL,0,&atx[292]} ,
  {0, "apply-to-parts" ,128,8,0,0,1,0,0,0,&avnx[496],&atx[35],NULL,0,&atx[293]} ,
  {0, "only-seg-num" ,128,9,0,0,1,0,0,0,&avnx[497],&atx[17],NULL,0,&atx[294]} ,
  {0, "fields" ,128,10,0,1,0,0,0,0,NULL,&atx[295],NULL,0,&atx[302]} ,
  {415, "Feat-qual-legal-set" ,1,0,0,0,0,0,0,0,NULL,&atx[230],&atx[296],0,&atx[25]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[297],NULL,0,NULL} ,
  {414, "Feat-qual-legal-val-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[298],0,&atx[295]} ,
  {0, "qual" ,128,0,0,0,0,0,0,0,NULL,&atx[299],NULL,0,NULL} ,
  {413, "Feat-qual-legal-val" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[300],0,&atx[297]} ,
  {0, "qual" ,128,0,0,0,0,0,0,0,NULL,&atx[27],NULL,0,&atx[301]} ,
  {0, "val" ,128,1,0,0,0,0,0,0,NULL,&atx[31],NULL,0,NULL} ,
  {0, "src-fields" ,128,11,0,1,0,0,0,0,NULL,&atx[303],NULL,0,NULL} ,
  {431, "Source-qual-val-set" ,1,0,0,0,0,0,0,0,NULL,&atx[230],&atx[304],0,&atx[54]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[305],NULL,0,NULL} ,
  {430, "Source-qual-val-choice" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[306],0,&atx[303]} ,
  {0, "textqual" ,128,0,0,0,0,0,0,0,NULL,&atx[307],NULL,0,&atx[310]} ,
  {429, "Source-qual-text-val" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[308],0,&atx[305]} ,
  {0, "srcqual" ,128,0,0,0,0,0,0,0,NULL,&atx[10],NULL,0,&atx[309]} ,
  {0, "val" ,128,1,0,0,0,0,0,0,NULL,&atx[31],NULL,0,NULL} ,
  {0, "location" ,128,1,0,0,0,0,0,0,NULL,&atx[13],NULL,0,&atx[311]} ,
  {0, "origin" ,128,2,0,0,0,0,0,0,NULL,&atx[15],NULL,0,&atx[312]} ,
  {0, "gcode" ,128,3,0,0,0,0,0,0,NULL,&atx[17],NULL,0,&atx[313]} ,
  {0, "mgcode" ,128,4,0,0,0,0,0,0,NULL,&atx[17],NULL,0,NULL} ,
  {0, "remove-feature" ,128,3,0,0,0,0,0,0,NULL,&atx[315],NULL,0,&atx[318]} ,
  {492, "Remove-feature-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[316],0,&atx[325]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[23],NULL,0,&atx[317]} ,
  {0, "constraint" ,128,1,0,1,0,0,0,0,NULL,&atx[174],NULL,0,NULL} ,
  {0, "convert-feature" ,128,4,0,0,0,0,0,0,NULL,&atx[319],NULL,0,&atx[342]} ,
  {499, "Convert-feature-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[320],0,&atx[350]} ,
  {0, "type-from" ,128,0,0,0,0,0,0,0,NULL,&atx[23],NULL,0,&atx[321]} ,
  {0, "type-to" ,128,1,0,0,0,0,0,0,NULL,&atx[23],NULL,0,&atx[322]} ,
  {0, "src-options" ,128,2,0,1,0,0,0,0,NULL,&atx[323],NULL,0,&atx[329]} ,
  {494, "Convert-feature-src-options" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[324],0,&atx[332]} ,
  {0, "cds" ,128,0,0,0,0,0,0,0,NULL,&atx[325],NULL,0,NULL} ,
  {493, "Convert-from-CDS-options" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[326],0,&atx[323]} ,
  {0, "remove-mRNA" ,128,0,0,0,0,0,0,0,NULL,&atx[35],NULL,0,&atx[327]} ,
  {0, "remove-gene" ,128,1,0,0,0,0,0,0,NULL,&atx[35],NULL,0,&atx[328]} ,
  {0, "remove-transcript-id" ,128,2,0,0,0,0,0,0,NULL,&atx[35],NULL,0,NULL} ,
  {0, "dst-options" ,128,3,0,1,0,0,0,0,NULL,&atx[330],NULL,0,&atx[340]} ,
  {498, "Convert-feature-dst-options" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[331],0,&atx[319]} ,
  {0, "bond" ,128,0,0,0,0,0,0,0,NULL,&atx[332],NULL,0,&atx[333]} ,
  {495, "Bond-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[498],0,&atx[334]} ,
  {0, "site" ,128,1,0,0,0,0,0,0,NULL,&atx[334],NULL,0,&atx[335]} ,
  {496, "Site-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[503],0,&atx[336]} ,
  {0, "region" ,128,2,0,0,0,0,0,0,NULL,&atx[336],NULL,0,&atx[338]} ,
  {497, "Region-type" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[337],0,&atx[330]} ,
  {0, "create-nucleotide" ,128,0,0,0,0,0,0,0,NULL,&atx[35],NULL,0,NULL} ,
  {0, "ncrna-class" ,128,3,0,0,0,0,0,0,NULL,&atx[31],NULL,0,&atx[339]} ,
  {0, "remove-original" ,128,4,0,0,0,0,0,0,NULL,&atx[35],NULL,0,NULL} ,
  {0, "leave-original" ,128,4,0,0,0,0,0,0,NULL,&atx[35],NULL,0,&atx[341]} ,
  {0, "src-feat-constraint" ,128,5,0,1,0,0,0,0,NULL,&atx[174],NULL,0,NULL} ,
  {0, "edit-location" ,128,5,0,0,0,0,0,0,NULL,&atx[343],NULL,0,&atx[370]} ,
  {511, "Edit-feature-location-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[344],0,&atx[383]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[23],NULL,0,&atx[345]} ,
  {0, "action" ,128,1,0,0,0,0,0,0,NULL,&atx[346],NULL,0,&atx[369]} ,
  {510, "Location-edit-type" ,1,0,0,0,0,0,0,0,NULL,&atx[19],&atx[347],0,&atx[343]} ,
  {0, "strand" ,128,0,0,0,0,0,0,0,NULL,&atx[348],NULL,0,&atx[353]} ,
  {502, "Edit-location-strand" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[349],0,&atx[356]} ,
  {0, "strand-from" ,128,0,0,0,0,0,0,0,NULL,&atx[350],NULL,0,&atx[351]} ,
  {500, "Feature-location-strand-from" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[530],0,&atx[352]} ,
  {0, "strand-to" ,128,1,0,0,0,0,0,0,NULL,&atx[352],NULL,0,NULL} ,
  {501, "Feature-location-strand-to" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[535],0,&atx[348]} ,
  {0, "set-5-partial" ,128,1,0,0,0,0,0,0,NULL,&atx[354],NULL,0,&atx[358]} ,
  {504, "Partial-5-set-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[355],0,&atx[359]} ,
  {0, "constraint" ,128,0,0,0,0,0,0,0,NULL,&atx[356],NULL,0,&atx[357]} ,
  {503, "Partial-5-set-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[540],0,&atx[354]} ,
  {0, "extend" ,128,1,0,0,0,0,0,0,NULL,&atx[35],NULL,0,NULL} ,
  {0, "clear-5-partial" ,128,2,0,0,0,0,0,0,NULL,&atx[359],NULL,0,&atx[360]} ,
  {505, "Partial-5-clear-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[544],0,&atx[363]} ,
  {0, "set-3-partial" ,128,3,0,0,0,0,0,0,NULL,&atx[361],NULL,0,&atx[365]} ,
  {507, "Partial-3-set-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[362],0,&atx[366]} ,
  {0, "constraint" ,128,0,0,0,0,0,0,0,NULL,&atx[363],NULL,0,&atx[364]} ,
  {506, "Partial-3-set-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[547],0,&atx[361]} ,
  {0, "extend" ,128,1,0,0,0,0,0,0,NULL,&atx[35],NULL,0,NULL} ,
  {0, "clear-3-partial" ,128,4,0,0,0,0,0,0,NULL,&atx[366],NULL,0,&atx[367]} ,
  {508, "Partial-3-clear-constraint" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[550],0,&atx[368]} ,
  {0, "convert" ,128,5,0,0,0,0,0,0,NULL,&atx[368],NULL,0,NULL} ,
  {509, "Convert-location-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[553],0,&atx[346]} ,
  {0, "constraint" ,128,2,0,1,0,0,0,0,NULL,&atx[174],NULL,0,NULL} ,
  {0, "remove-descriptor" ,128,6,0,0,0,0,0,0,NULL,&atx[371],NULL,0,&atx[375]} ,
  {514, "Remove-descriptor-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[372],0,&atx[380]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[373],NULL,0,&atx[374]} ,
  {513, "Descriptor-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[556],0,&atx[371]} ,
  {0, "constraint" ,128,1,0,1,0,0,0,0,NULL,&atx[174],NULL,0,NULL} ,
  {0, "autodef" ,128,7,0,0,0,0,0,0,NULL,&atx[376],NULL,0,NULL} ,
  {516, "Autodef-action" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[377],0,&atx[268]} ,
  {0, "modifiers" ,128,0,0,1,0,0,0,0,NULL,&atx[230],&atx[378],0,&atx[379]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[10],NULL,0,NULL} ,
  {0, "clause-list-type" ,128,1,0,0,0,0,0,0,NULL,&atx[380],NULL,0,NULL} ,
  {515, "Autodef-list-type" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&avnx[568],0,&atx[376]} ,
  {448, "Molinfo-field-list" ,1,0,0,0,0,0,0,0,NULL,&atx[230],&atx[382],0,&atx[70]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[56],NULL,0,NULL} ,
  {512, "Molinfo-block" ,1,0,0,0,0,0,0,0,NULL,&atx[38],&atx[384],0,&atx[373]} ,
  {0, "to-list" ,128,0,0,0,0,0,0,0,NULL,&atx[381],NULL,0,&atx[385]} ,
  {0, "from-list" ,128,1,0,1,0,0,0,0,NULL,&atx[381],NULL,0,&atx[386]} ,
  {0, "constraint" ,128,2,0,1,0,0,0,0,NULL,&atx[174],NULL,0,NULL} };

static AsnModule ampx[1] = {
  { "NCBI-Macro" , "asnmacro.h54",&atx[0],NULL,NULL,0,0} };

static AsnValxNodePtr avn = avnx;
static AsnTypePtr at = atx;
static AsnModulePtr amp = ampx;



/**************************************************
*
*    Defines for Module NCBI-Macro
*
**************************************************/

#define AECR_ACTION &at[0]
#define AECR_ACTION_action &at[1]
#define AECR_ACTION_also_change_mrna &at[172]
#define AECR_ACTION_constraint &at[173]

#define PARSE_ACTION &at[231]
#define PARSE_ACTION_portion &at[232]
#define PARSE_ACTION_src &at[233]
#define PARSE_ACTION_dest &at[249]
#define PARSE_ACTION_capitalization &at[262]
#define PARSE_ACTION_remove_from_parsed &at[264]
#define PARSE_ACTION_existing_text &at[265]

#define MACRO_ACTION_LIST &at[266]
#define MACRO_ACTION_LIST_E &at[267]

#define STRING_LOCATION &at[33]

#define STRING_CONSTRAINT &at[29]
#define STRING_CONSTRAINT_match_text &at[30]
#define CONSTRAINT_match_location &at[32]
#define CONSTRAINT_case_sensitive &at[34]
#define STRING_CONSTRAINT_whole_word &at[36]
#define STRING_CONSTRAINT_not_present &at[37]

#define STRAND_CONSTRAINT &at[181]

#define SEQTYPE_CONSTRAINT &at[183]

#define PARTIAL_CONSTRAINT &at[185]

#define LOCATION_CONSTRAINT &at[179]
#define LOCATION_CONSTRAINT_strand &at[180]
#define LOCATION_CONSTRAINT_seq_type &at[182]
#define LOCATION_CONSTRAINT_partial5 &at[184]
#define LOCATION_CONSTRAINT_partial3 &at[186]

#define OBJECT_TYPE_CONSTRAINT &at[197]

#define FEATURE_TYPE &at[23]

#define FEAT_QUAL_LEGAL &at[27]

#define FEAT_QUAL_LEGAL_VAL &at[299]
#define FEAT_QUAL_LEGAL_VAL_qual &at[300]
#define FEAT_QUAL_LEGAL_VAL_val &at[301]

#define FEAT_QUAL_LEGAL_VAL_CHOICE &at[297]
#define FEAT_QUAL_LEGAL_VAL_CHOICE_qual &at[298]

#define FEAT_QUAL_LEGAL_SET &at[295]
#define FEAT_QUAL_LEGAL_SET_E &at[296]

#define FEAT_QUAL_CHOICE &at[25]
#define FEAT_QUAL_CHOICE_legal_qual &at[26]
#define FEAT_QUAL_CHOICE_illegal_qual &at[28]

#define FEATURE_FIELD &at[21]
#define FEATURE_FIELD_type &at[22]
#define FEATURE_FIELD_field &at[24]

#define FEATURE_FIELD_LEGAL &at[257]
#define FEATURE_FIELD_LEGAL_type &at[258]
#define FEATURE_FIELD_LEGAL_field &at[259]

#define FEATURE_FIELD_PAIR &at[99]
#define FEATURE_FIELD_PAIR_type &at[100]
#define FEATURE_FIELD_PAIR_field_from &at[101]
#define FEATURE_FIELD_PAIR_field_to &at[102]

#define RNA_FEAT_TYPE &at[42]
#define RNA_FEAT_TYPE_preRNA &at[43]
#define RNA_FEAT_TYPE_mRNA &at[45]
#define RNA_FEAT_TYPE_tRNA &at[46]
#define RNA_FEAT_TYPE_rRNA &at[47]
#define RNA_FEAT_TYPE_ncRNA &at[48]
#define RNA_FEAT_TYPE_tmRNA &at[49]
#define RNA_FEAT_TYPE_miscRNA &at[50]

#define RNA_FIELD &at[52]

#define RNA_QUAL &at[40]
#define RNA_QUAL_type &at[41]
#define RNA_QUAL_field &at[51]

#define RNA_QUAL_PAIR &at[104]
#define RNA_QUAL_PAIR_type &at[105]
#define RNA_QUAL_PAIR_field_from &at[106]
#define RNA_QUAL_PAIR_field_to &at[107]

#define SOURCE_QUAL &at[10]

#define SOURCE_QUAL_PAIR &at[95]
#define SOURCE_QUAL_PAIR_field_from &at[96]
#define SOURCE_QUAL_PAIR_field_to &at[97]

#define SOURCE_LOCATION &at[13]

#define SOURCE_ORIGIN &at[15]

#define SOURCE_QUAL_CHOICE &at[8]
#define SOURCE_QUAL_CHOICE_textqual &at[9]
#define SOURCE_QUAL_CHOICE_location &at[12]
#define SOURCE_QUAL_CHOICE_origin &at[14]
#define SOURCE_QUAL_CHOICE_gcode &at[16]
#define SOURCE_QUAL_CHOICE_mgcode &at[18]

#define SOURCE_QUAL_TEXT_VAL &at[307]
#define SOURCE_QUAL_TEXT_VAL_srcqual &at[308]
#define SOURCE_QUAL_TEXT_VAL_val &at[309]

#define SOURCE_QUAL_VAL_CHOICE &at[305]
#define SOURCE_QUAL_VAL_CHOICE_textqual &at[306]
#define SOURCE_QUAL_VAL_CHOICE_location &at[310]
#define SOURCE_QUAL_VAL_CHOICE_origin &at[311]
#define SOURCE_QUAL_VAL_CHOICE_gcode &at[312]
#define SOURCE_QUAL_VAL_CHOICE_mgcode &at[313]

#define SOURCE_QUAL_VAL_SET &at[303]
#define SOURCE_QUAL_VAL_SET_E &at[304]

#define CDSGENEPROT_FIELD &at[54]

#define CDSGENEPROT_FIELD_PAIR &at[109]
#define FIELD_PAIR_field_from &at[110]
#define CDSGENEPROT_FIELD_PAIR_field_to &at[111]

#define MOLECULE_TYPE &at[58]

#define TECHNIQUE_TYPE &at[60]

#define COMPLETEDNESS_TYPE &at[62]

#define MOLECULE_CLASS_TYPE &at[64]

#define TOPOLOGY_TYPE &at[66]

#define STRAND_TYPE &at[68]

#define MOLINFO_FIELD &at[56]
#define MOLINFO_FIELD_molecule &at[57]
#define MOLINFO_FIELD_technique &at[59]
#define MOLINFO_FIELD_completedness &at[61]
#define MOLINFO_FIELD_mol_class &at[63]
#define MOLINFO_FIELD_topology &at[65]
#define MOLINFO_FIELD_strand &at[67]

#define MOLINFO_MOLECULE_PAIR &at[115]
#define MOLINFO_MOLECULE_PAIR_from &at[116]
#define MOLINFO_MOLECULE_PAIR_to &at[117]

#define MOLINFO_TECHNIQUE_PAIR &at[119]
#define MOLINFO_TECHNIQUE_PAIR_from &at[120]
#define MOLINFO_TECHNIQUE_PAIR_to &at[121]

#define MOLINFO_COMPLETEDNESS_PAIR &at[123]
#define MOLINFO_COMPLETEDNESS_PAIR_from &at[124]
#define MOLINFO_COMPLETEDNESS_PAIR_to &at[125]

#define MOLINFO_MOL_CLASS_PAIR &at[127]
#define MOLINFO_MOL_CLASS_PAIR_from &at[128]
#define MOLINFO_MOL_CLASS_PAIR_to &at[129]

#define MOLINFO_TOPOLOGY_PAIR &at[131]
#define MOLINFO_TOPOLOGY_PAIR_from &at[132]
#define MOLINFO_TOPOLOGY_PAIR_to &at[133]

#define MOLINFO_STRAND_PAIR &at[135]
#define MOLINFO_STRAND_PAIR_from &at[136]
#define MOLINFO_STRAND_PAIR_to &at[137]

#define MOLINFO_FIELD_PAIR &at[113]
#define MOLINFO_FIELD_PAIR_molecule &at[114]
#define MOLINFO_FIELD_PAIR_technique &at[118]
#define FIELD_PAIR_completedness &at[122]
#define MOLINFO_FIELD_PAIR_mol_class &at[126]
#define MOLINFO_FIELD_PAIR_topology &at[130]
#define MOLINFO_FIELD_PAIR_strand &at[134]

#define MOLINFO_FIELD_LIST &at[381]
#define MOLINFO_FIELD_LIST_E &at[382]

#define PUBLICATION_FIELD &at[70]

#define STRUCTURED_COMMENT_FIELD &at[72]
#define COMMENT_FIELD_database &at[73]
#define STRUCTURED_COMMENT_FIELD_named &at[74]
#define COMMENT_FIELD_field_name &at[75]

#define STRUCTURED_COMMENT_FIELD_PAIR &at[139]
#define COMMENT_FIELD_PAIR_from &at[140]
#define COMMENT_FIELD_PAIR_to &at[141]

#define MISC_FIELD &at[77]

#define PUB_TYPE &at[225]

#define PUB_FIELD_CONSTRAINT &at[227]
#define PUB_FIELD_CONSTRAINT_field &at[228]
#define PUB_FIELD_CONSTRAINT_constraint &at[229]

#define PUBLICATION_CONSTRAINT &at[223]
#define PUBLICATION_CONSTRAINT_type &at[224]
#define PUBLICATION_CONSTRAINT_field &at[226]

#define SOURCE_CONSTRAINT &at[192]
#define SOURCE_CONSTRAINT_field1 &at[193]
#define SOURCE_CONSTRAINT_field2 &at[194]
#define SOURCE_CONSTRAINT_constraint &at[195]
#define CONSTRAINT_type_constraint &at[196]

#define FEATURE_TYPE_CONSTRAINT &at[208]

#define CDSGENEPROT_PSEUDO_CONSTRAINT &at[206]
#define PSEUDO_CONSTRAINT_feature &at[207]
#define PSEUDO_CONSTRAINT_is_pseudo &at[209]

#define CDSGENEPROT_CONSTRAINT_FIELD &at[201]
#define CONSTRAINT_FIELD_field &at[202]

#define CDSGENEPROT_QUAL_CONSTRAINT &at[199]
#define QUAL_CONSTRAINT_field1 &at[200]
#define QUAL_CONSTRAINT_field2 &at[203]
#define QUAL_CONSTRAINT_constraint &at[204]

#define FIELD_CONSTRAINT &at[188]
#define FIELD_CONSTRAINT_field &at[189]
#define CONSTRAINT_string_constraint &at[190]

#define FIELD_TYPE &at[6]
#define FIELD_TYPE_source_qual &at[7]
#define FIELD_TYPE_feature_field &at[20]
#define FIELD_TYPE_rna_field &at[39]
#define FIELD_TYPE_cds_gene_prot &at[53]
#define FIELD_TYPE_molinfo_field &at[55]
#define FIELD_TYPE_pub &at[69]
#define FIELD_TYPE_struc_comment_field &at[71]
#define FIELD_TYPE_misc &at[76]

#define SEQUENCE_CONSTRAINT_RNAMOL &at[218]

#define CONSTRAINT_MOL_TYPE_CONSTRAINT &at[213]
#define MOL_TYPE_CONSTRAINT_any &at[214]
#define MOL_TYPE_CONSTRAINT_nucleotide &at[215]
#define MOL_TYPE_CONSTRAINT_dna &at[216]
#define MOL_TYPE_CONSTRAINT_rna &at[217]
#define MOL_TYPE_CONSTRAINT_protein &at[219]

#define SEQUENCE_CONSTRAINT &at[211]
#define SEQUENCE_CONSTRAINT_seqtype &at[212]
#define SEQUENCE_CONSTRAINT_id &at[220]
#define SEQUENCE_CONSTRAINT_feature &at[221]

#define CONSTRAINT_CHOICE &at[176]
#define CONSTRAINT_CHOICE_string &at[177]
#define CONSTRAINT_CHOICE_location &at[178]
#define CONSTRAINT_CHOICE_field &at[187]
#define CONSTRAINT_CHOICE_source &at[191]
#define CHOICE_cdsgeneprot_qual &at[198]
#define CHOICE_cdsgeneprot_pseudo &at[205]
#define CONSTRAINT_CHOICE_sequence &at[210]
#define CONSTRAINT_CHOICE_pub &at[222]

#define CONSTRAINT_CHOICE_SET &at[174]
#define CONSTRAINT_CHOICE_SET_E &at[175]

#define TEXT_PORTION &at[159]
#define TEXT_PORTION_left_text &at[160]
#define TEXT_PORTION_include_left &at[161]
#define TEXT_PORTION_right_text &at[162]
#define TEXT_PORTION_include_right &at[163]
#define TEXT_PORTION_inside &at[164]
#define TEXT_PORTION_case_sensitive &at[165]
#define TEXT_PORTION_whole_word &at[166]

#define FIELD_EDIT_LOCATION &at[88]

#define FIELD_EDIT &at[84]
#define FIELD_EDIT_find_txt &at[85]
#define FIELD_EDIT_repl_txt &at[86]
#define FIELD_EDIT_location &at[87]

#define FIELD_PAIR_TYPE &at[93]
#define FIELD_PAIR_TYPE_source_qual &at[94]
#define FIELD_PAIR_TYPE_feature_field &at[98]
#define FIELD_PAIR_TYPE_rna_field &at[103]
#define FIELD_PAIR_TYPE_cds_gene_prot &at[108]
#define FIELD_PAIR_TYPE_molinfo_field &at[112]
#define PAIR_TYPE_struc_comment_field &at[138]

#define EXISTINGTEXTOPTION &at[80]

#define APPLY_ACTION &at[4]
#define APPLY_ACTION_field &at[5]
#define APPLY_ACTION_value &at[78]
#define APPLY_ACTION_existing_text &at[79]

#define EDIT_ACTION &at[82]
#define EDIT_ACTION_edit &at[83]
#define EDIT_ACTION_field &at[89]

#define CONVERT_ACTION &at[91]
#define CONVERT_ACTION_fields &at[92]
#define CONVERT_ACTION_strip_name &at[142]
#define CONVERT_ACTION_keep_original &at[143]
#define CONVERT_ACTION_existing_text &at[144]

#define COPY_ACTION &at[146]
#define COPY_ACTION_fields &at[147]
#define COPY_ACTION_existing_text &at[148]

#define SWAP_ACTION &at[150]
#define SWAP_ACTION_fields &at[151]
#define SWAP_ACTION_field_to &at[152]

#define AECRPARSE_ACTION &at[157]
#define AECRPARSE_ACTION_portion &at[158]
#define AECRPARSE_ACTION_fields &at[167]
#define ACTION_remove_from_parsed &at[168]
#define AECRPARSE_ACTION_remove_left &at[169]
#define AECRPARSE_ACTION_remove_right &at[170]
#define AECRPARSE_ACTION_existing_text &at[171]

#define REMOVE_ACTION &at[154]
#define REMOVE_ACTION_field &at[155]

#define ACTION_CHOICE &at[2]
#define ACTION_CHOICE_apply &at[3]
#define ACTION_CHOICE_edit &at[81]
#define ACTION_CHOICE_convert &at[90]
#define ACTION_CHOICE_copy &at[145]
#define ACTION_CHOICE_swap &at[149]
#define ACTION_CHOICE_remove &at[153]
#define ACTION_CHOICE_parse &at[156]

#define CAP_CHANGE &at[263]

#define PARSE_SRC_ORG_CHOICE &at[241]
#define SRC_ORG_CHOICE_source_qual &at[242]
#define CHOICE_taxname_after_binomial &at[243]

#define PARSE_SRC_ORG &at[239]
#define PARSE_SRC_ORG_field &at[240]
#define PARSE_SRC_ORG_type &at[244]

#define PARSE_SRC &at[234]
#define PARSE_SRC_defline &at[235]
#define PARSE_SRC_flatfile &at[236]
#define PARSE_SRC_local_id &at[237]
#define PARSE_SRC_org &at[238]
#define PARSE_SRC_comment &at[245]
#define PARSE_SRC_bankit_comment &at[246]
#define PARSE_SRC_structured_comment &at[247]
#define PARSE_SRC_file_id &at[248]

#define PARSE_DST_ORG &at[253]
#define PARSE_DST_ORG_field &at[254]
#define PARSE_DST_ORG_type &at[255]

#define PARSE_DEST &at[250]
#define PARSE_DEST_defline &at[251]
#define PARSE_DEST_org &at[252]
#define PARSE_DEST_featqual &at[256]
#define PARSE_DEST_comment_descriptor &at[260]
#define PARSE_DEST_dbxref &at[261]

#define LOCATION_INTERVAL &at[280]
#define LOCATION_INTERVAL_from &at[281]
#define LOCATION_INTERVAL_to &at[282]

#define LOCATION_CHOICE &at[278]
#define LOCATION_CHOICE_interval &at[279]
#define LOCATION_CHOICE_whole_sequence &at[283]

#define SEQUENCE_LIST &at[287]
#define SEQUENCE_LIST_E &at[288]

#define SEQUENCE_LIST_CHOICE &at[285]
#define SEQUENCE_LIST_CHOICE_list &at[286]
#define SEQUENCE_LIST_CHOICE_all &at[289]

#define APPLY_FEATURE_ACTION &at[272]
#define APPLY_FEATURE_ACTION_type &at[273]
#define APPLY_FEATURE_ACTION_partial5 &at[274]
#define APPLY_FEATURE_ACTION_partial3 &at[275]
#define FEATURE_ACTION_plus_strand &at[276]
#define APPLY_FEATURE_ACTION_location &at[277]
#define APPLY_FEATURE_ACTION_seq_list &at[284]
#define FEATURE_ACTION_add_redundant &at[290]
#define APPLY_FEATURE_ACTION_add_mrna &at[291]
#define FEATURE_ACTION_apply_to_parts &at[292]
#define FEATURE_ACTION_only_seg_num &at[293]
#define APPLY_FEATURE_ACTION_fields &at[294]
#define APPLY_FEATURE_ACTION_src_fields &at[302]

#define REMOVE_FEATURE_ACTION &at[315]
#define REMOVE_FEATURE_ACTION_type &at[316]
#define FEATURE_ACTION_constraint &at[317]

#define CONVERT_FROM_CDS_OPTIONS &at[325]
#define FROM_CDS_OPTIONS_remove_mRNA &at[326]
#define FROM_CDS_OPTIONS_remove_gene &at[327]
#define OPTIONS_remove_transcript_id &at[328]

#define CONVERT_FEATURE_SRC_OPTIONS &at[323]
#define CONVERT_FEATURE_SRC_OPTIONS_cds &at[324]

#define BOND_TYPE &at[332]

#define SITE_TYPE &at[334]

#define REGION_TYPE &at[336]
#define REGION_TYPE_create_nucleotide &at[337]

#define CONVERT_FEATURE_DST_OPTIONS &at[330]
#define FEATURE_DST_OPTIONS_bond &at[331]
#define FEATURE_DST_OPTIONS_site &at[333]
#define FEATURE_DST_OPTIONS_region &at[335]
#define DST_OPTIONS_ncrna_class &at[338]
#define DST_OPTIONS_remove_original &at[339]

#define CONVERT_FEATURE_ACTION &at[319]
#define FEATURE_ACTION_type_from &at[320]
#define CONVERT_FEATURE_ACTION_type_to &at[321]
#define FEATURE_ACTION_src_options &at[322]
#define FEATURE_ACTION_dst_options &at[329]
#define FEATURE_ACTION_leave_original &at[340]
#define ACTION_src_feat_constraint &at[341]

#define FEATURE_LOCATION_STRAND_FROM &at[350]

#define FEATURE_LOCATION_STRAND_TO &at[352]

#define EDIT_LOCATION_STRAND &at[348]
#define LOCATION_STRAND_strand_from &at[349]
#define EDIT_LOCATION_STRAND_strand_to &at[351]

#define PARTIAL_5_SET_CONSTRAINT &at[356]

#define PARTIAL_5_SET_ACTION &at[354]
#define PARTIAL_5_SET_ACTION_constraint &at[355]
#define PARTIAL_5_SET_ACTION_extend &at[357]

#define PARTIAL_5_CLEAR_CONSTRAINT &at[359]

#define PARTIAL_3_SET_CONSTRAINT &at[363]

#define PARTIAL_3_SET_ACTION &at[361]
#define PARTIAL_3_SET_ACTION_constraint &at[362]
#define PARTIAL_3_SET_ACTION_extend &at[364]

#define PARTIAL_3_CLEAR_CONSTRAINT &at[366]

#define CONVERT_LOCATION_TYPE &at[368]

#define LOCATION_EDIT_TYPE &at[346]
#define LOCATION_EDIT_TYPE_strand &at[347]
#define EDIT_TYPE_set_5_partial &at[353]
#define EDIT_TYPE_clear_5_partial &at[358]
#define EDIT_TYPE_set_3_partial &at[360]
#define EDIT_TYPE_clear_3_partial &at[365]
#define LOCATION_EDIT_TYPE_convert &at[367]

#define EDIT_FEATURE_LOCATION_ACTION &at[343]
#define FEATURE_LOCATION_ACTION_type &at[344]
#define FEATURE_LOCATION_ACTION_action &at[345]
#define LOCATION_ACTION_constraint &at[369]

#define MOLINFO_BLOCK &at[383]
#define MOLINFO_BLOCK_to_list &at[384]
#define MOLINFO_BLOCK_from_list &at[385]
#define MOLINFO_BLOCK_constraint &at[386]

#define DESCRIPTOR_TYPE &at[373]

#define REMOVE_DESCRIPTOR_ACTION &at[371]
#define REMOVE_DESCRIPTOR_ACTION_type &at[372]
#define DESCRIPTOR_ACTION_constraint &at[374]

#define AUTODEF_LIST_TYPE &at[380]

#define AUTODEF_ACTION &at[376]
#define AUTODEF_ACTION_modifiers &at[377]
#define AUTODEF_ACTION_modifiers_E &at[378]
#define AUTODEF_ACTION_clause_list_type &at[379]

#define MACRO_ACTION_CHOICE &at[268]
#define MACRO_ACTION_CHOICE_aecr &at[269]
#define MACRO_ACTION_CHOICE_parse &at[270]
#define MACRO_ACTION_CHOICE_add_feature &at[271]
#define ACTION_CHOICE_remove_feature &at[314]
#define ACTION_CHOICE_convert_feature &at[318]
#define ACTION_CHOICE_edit_location &at[342]
#define CHOICE_remove_descriptor &at[370]
#define MACRO_ACTION_CHOICE_autodef &at[375]
